#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 rfc5051
version:              0.2
visibility:           public
id:                   rfc5051-0.2-A1NqzBzrf2C4eDVtJNlUQB
key:                  rfc5051-0.2-A1NqzBzrf2C4eDVtJNlUQB
license:              BSD-3-Clause
copyright:            (C) 2013 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
synopsis:             Simple unicode collation as per RFC5051.
description:
    This library implements @i;unicode-casemap@,
    the simple, non locale-sensitive unicode collation
    algorithm described in RFC 5051 (<http://www.rfc-editor.org/rfc/rfc5051.txt>).
    Proper unicode collation can be done using text-icu, but that is a big
    dependency that depends on a large C library, and rfc5051 might be better
    for some purposes.

    Here is a list of strings sorted by the Prelude'\''s @sort@ function:

    Abe Oeb abe ab&#233; oeb &#193;be &#196;be &#212;eb &#225;be &#228;be &#244;eb.

    Here is the same list sorted by @sortBy compareUnicode@:

    Abe abe ab&#233; &#193;be &#225;be &#196;be &#228;be Oeb oeb &#212;eb &#244;eb

category:             Text
abi:                  342f5e8f0dc3c1537c720aec61fe9fd8
exposed:              True
exposed-modules:      Data.RFC5051
hidden-modules:       Data.RFC5051.UnicodeData
import-dirs:          /usr/lib/ghc-9.6.6/site-local/rfc5051-0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/rfc5051-0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/rfc5051-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rfc5051
hs-libraries:         HSrfc5051-0.2-A1NqzBzrf2C4eDVtJNlUQB
depends:              base-4.18.2.1 containers-0.6.7 text-2.0.2
haddock-interfaces:   /usr/share/doc/haskell-rfc5051/html/rfc5051.haddock
haddock-html:         /usr/share/doc/haskell-rfc5051/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

